@@ -1,12 +1,12 @@
 use std::{env, fs};
 
 use anyhow::{ensure, Context, Result};
-use clap::{AppSettings, Clap};
+use clap::{AppSettings, Parser};
 
 use crate::error::CrateError;
 
 /// Create a new Gear program
-#[derive(Clap, Debug)]
+#[derive(Debug, Parser)]
 #[clap(global_setting=AppSettings::DisableVersionFlag)]
 pub(crate) struct NewCommand {
     /// Project name
@@ -43,14 +43,7 @@ impl NewCommand {
 
     fn replace_fields(&self, source: &[u8]) -> Result<String> {
         let source = String::from_utf8(source.to_vec())?;
-        let result = source.replace("{{name}}", &self.name).replace(
-            "{{async}}",
-            if self.async_flag {
-                "gstd-async = { git = \"https://github.com/gear-tech/gear.git\" }\n"
-            } else {
-                ""
-            },
-        );
+        let result = source.replace("{{name}}", &self.name);
         Ok(result)
     }
 }
