@@ -1,8 +1,9 @@
 use std::process::{self, Command};
 
 use anyhow::Result;
+use colored::Colorize;
 
-pub(crate) fn run_cargo(args: Vec<&str>) -> Result<()> {
+pub fn run_cargo(args: Vec<&str>) -> Result<()> {
     let mut cargo = Command::new("cargo");
     cargo.arg("+nightly");
     cargo.args(args);
@@ -13,3 +14,7 @@ pub(crate) fn run_cargo(args: Vec<&str>) -> Result<()> {
     }
     Ok(())
 }
+
+pub fn print(label: &str, msg: &str) {
+    println!("{:>12} {}", label.green().bold(), msg,);
+}
