@@ -27,4 +27,10 @@ pub enum CrateError {
 
     #[error("unable to produce the metadata WASM file from `{0}`")]
     UnableToProduceMetadata(PathBuf),
+
+    #[error("unable to inject gas counter to the program `{0}`")]
+    UnableToInjectGasCounter(PathBuf),
+
+    #[error("JSON RPC error [{0}]: {1}")]
+    JsonRpcError(i16, String),
 }
