@@ -1,15 +1,16 @@
 mod commands;
 mod common;
-mod crate_info;
 mod error;
+mod output_info;
+mod runner;
 
 use anyhow::Result;
-use clap::Clap;
+use clap::Parser;
 
 use crate::commands::*;
 
 /// Utility to simplify Gear programs development
-#[derive(Clap, Debug)]
+#[derive(Debug, Parser)]
 #[clap(
     bin_name = "cargo",
     version = clap::crate_version!(),
@@ -19,7 +20,7 @@ struct Opts {
     command: Util,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Debug, Parser)]
 enum Util {
     #[clap(
         name = "program",
@@ -29,13 +30,13 @@ enum Util {
 }
 
 /// Utility to simplify Gear programs development
-#[derive(Clap, Debug)]
+#[derive(Debug, Parser)]
 struct ProgramUtil {
     #[clap(subcommand)]
     command: Command,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Debug, Parser)]
 enum Command {
     New(NewCommand),
     Build(BuildCommand),
@@ -50,7 +51,7 @@ pub fn run() -> Result<()> {
     let Util::Program(ProgramUtil { command }) = opts.command;
     match command {
         Command::New(command) => command.run(),
-        Command::Build(command) => command.run(),
+        Command::Build(command) => command.run().and(Ok(())),
         Command::Run(command) => command.run(),
         Command::Test(command) => command.run(),
         Command::Login(command) => command.run(),
